@@ -124,15 +124,15 @@ class mosqpp_EXPORT mosquittopp {
 		int socks5_set(const char *host, int port=1080, const char *username=NULL, const char *password=NULL);
 
 		// names in the functions commented to prevent unused parameter warning
-		virtual void on_connect(int /*rc*/) {return;}
-		virtual void on_connect_with_flags(int /*rc*/, int /*flags*/) {return;}
-		virtual void on_disconnect(int /*rc*/) {return;}
-		virtual void on_publish(int /*mid*/) {return;}
-		virtual void on_message(const struct mosquitto_message * /*message*/) {return;}
-		virtual void on_subscribe(int /*mid*/, int /*qos_count*/, const int * /*granted_qos*/) {return;}
-		virtual void on_unsubscribe(int /*mid*/) {return;}
-		virtual void on_log(int /*level*/, const char * /*str*/) {return;}
-		virtual void on_error() {return;}
+		virtual void MOSQ_USED on_connect(int /*rc*/) {return;}
+		virtual void MOSQ_USED on_connect_with_flags(int /*rc*/, int /*flags*/) {return;}
+		virtual void MOSQ_USED on_disconnect(int /*rc*/) {return;}
+		virtual void MOSQ_USED on_publish(int /*mid*/) {return;}
+		virtual void MOSQ_USED on_message(const struct mosquitto_message * /*message*/) {return;}
+		virtual void MOSQ_USED on_subscribe(int /*mid*/, int /*qos_count*/, const int * /*granted_qos*/) {return;}
+		virtual void MOSQ_USED on_unsubscribe(int /*mid*/) {return;}
+		virtual void MOSQ_USED on_log(int /*level*/, const char * /*str*/) {return;}
+		virtual void MOSQ_USED on_error() {return;}
 };
 
 }
